@@ -58,6 +58,8 @@ module TMail
 
   class HFdecoder
 
+    include TextUtils
+
     encoded = '=\?(?:iso-2022-jp|euc-jp|shift_jis)\?[QB]\?[a-z0-9+/=]+\?='
     ENCODED_WORDS = /#{encoded}(?:\s+#{encoded})*/i
 
@@ -116,7 +118,9 @@ module TMail
       @f << decode(str)
     end
 
-    alias phrase text
+    def phrase( str )
+      @f << quote_phrase(decode(str))
+    end
 
     def kv_pair( k, v )
       @f << k << '=' << v
